Learn R Programming

neuroUp (version 0.3.1)

vicar_char: Vicarious Charity task fMRI region of interest data

Description

A dataset containing the parameter estimates from the anatomical mask of the left nucleus accumbens (Harvard-Oxford subcortical atlas; thresholded at 40%; center-of-mass coordinates x = -10, y = 12, z = -7; 28 voxels included), with one value for the mean activation during gaining for self and one value for the mean activation during no-gain for self and charity for all participants.

Usage

vicar_char

Arguments

Format

A data frame with 156 rows and 4 variables:

participant_id

unique id for every participant

age

age in years (11.00-21.17)

nacc_selfgain

parameter estimates for the left nucleus accumbens during gaining for self (-5.66-3.05)

nacc_bothnogain

parameter estimates for the left nucleus accumbens during no-gain for self and charity (-6.44-2.97)